@@ -62,12 +62,12 @@ class GUIProcess(QObject):
         self.args = None
 
         self._proc = QProcess(self)
-        self._proc.errorOccurred.connect(self._on_error)  # type: ignore
-        self._proc.errorOccurred.connect(self.error)  # type: ignore
-        self._proc.finished.connect(self._on_finished)  # type: ignore
-        self._proc.finished.connect(self.finished)  # type: ignore
-        self._proc.started.connect(self._on_started)  # type: ignore
-        self._proc.started.connect(self.started)  # type: ignore
+        self._proc.errorOccurred.connect(self._on_error)
+        self._proc.errorOccurred.connect(self.error)  # type: ignore[arg-type]
+        self._proc.finished.connect(self._on_finished)
+        self._proc.finished.connect(self.finished)  # type: ignore[arg-type]
+        self._proc.started.connect(self._on_started)
+        self._proc.started.connect(self.started)  # type: ignore[arg-type]
 
         if additional_env is not None:
             procenv = QProcessEnvironment.systemEnvironment()
@@ -89,9 +89,9 @@ class GUIProcess(QObject):
             code, status))
 
         encoding = locale.getpreferredencoding(do_setlocale=False)
-        stderr = bytes(self._proc.readAllStandardError()).decode(
+        stderr = self._proc.readAllStandardError().data().decode(
             encoding, 'replace')
-        stdout = bytes(self._proc.readAllStandardOutput()).decode(
+        stdout = self._proc.readAllStandardOutput().data().decode(
             encoding, 'replace')
 
         if self._output_messages:
@@ -163,7 +163,8 @@ class GUIProcess(QObject):
         """Convenience wrapper around QProcess::startDetached."""
         log.procs.debug("Starting detached.")
         self._pre_start(cmd, args)
-        ok, _pid = self._proc.startDetached(cmd, args, None)  # type: ignore
+        ok, _pid = self._proc.startDetached(
+            cmd, args, None)  # type: ignore[call-arg]
 
         if not ok:
             message.error("Error while spawning {}".format(self._what))
