@@ -1,6 +1,6 @@
 # vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
 
-# Copyright 2014-2019 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+# Copyright 2014-2020 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
 # This file is part of qutebrowser.
 #
@@ -22,6 +22,7 @@
 import os
 import os.path
 import contextlib
+import typing
 
 from PyQt5.QtCore import pyqtSlot, pyqtSignal, QObject
 
@@ -149,7 +150,7 @@ class LineParser(BaseLineParser):
         """
         super().__init__(configdir, fname, binary=binary, parent=parent)
         if not os.path.isfile(self._configfile):
-            self.data = []
+            self.data = []  # type: typing.Sequence[str]
         else:
             log.init.debug("Reading {}".format(self._configfile))
             self._read()
