@@ -635,6 +635,19 @@ class TestWritePy:
         lines = confpy.read_text('utf-8').splitlines()
         assert '# Autogenerated config.py' in lines
 
+    @pytest.mark.posix
+    def test_expanduser(self, commands, monkeypatch, tmpdir):
+        """Make sure that using a path with ~/... works correctly."""
+        home = tmpdir / 'home'
+        home.ensure(dir=True)
+        monkeypatch.setenv('HOME', str(home))
+
+        commands.config_write_py('~/config.py')
+
+        confpy = home / 'config.py'
+        lines = confpy.read_text('utf-8').splitlines()
+        assert '# Autogenerated config.py' in lines
+
     def test_existing_file(self, commands, tmpdir):
         confpy = tmpdir / 'config.py'
         confpy.ensure()
