@@ -344,12 +344,10 @@ class TestLateInit:
         # fonts.default_family and font settings customized
         # https://github.com/qutebrowser/qutebrowser/issues/3096
         ([('fonts.default_family', 'Comic Sans MS'),
-          ('fonts.tabs', '12pt default_family'),
           ('fonts.keyhint', '12pt default_family')], 12, 'Comic Sans MS'),
         # as above, but with default_size
         ([('fonts.default_family', 'Comic Sans MS'),
           ('fonts.default_size', '23pt'),
-          ('fonts.tabs', 'default_size default_family'),
           ('fonts.keyhint', 'default_size default_family')],
          23, 'Comic Sans MS'),
     ])
@@ -381,10 +379,6 @@ class TestLateInit:
         # Font
         expected = '{}pt "{}"'.format(size, family)
         assert config.instance.get('fonts.keyhint') == expected
-        # QtFont
-        font = config.instance.get('fonts.tabs')
-        assert font.pointSize() == size
-        assert font.family() == family
 
     @pytest.fixture
     def run_configinit(self, init_patch, fake_save_manager, args):
@@ -405,10 +399,6 @@ class TestLateInit:
 
         assert 'fonts.keyhint' in changed_options  # Font
         assert config.instance.get('fonts.keyhint') == '23pt "Comic Sans MS"'
-        assert 'fonts.tabs' in changed_options  # QtFont
-        tabs_font = config.instance.get('fonts.tabs')
-        assert tabs_font.family() == 'Comic Sans MS'
-        assert tabs_font.pointSize() == 23
 
         # Font subclass, but doesn't end with "default_family"
         assert 'fonts.web.family.standard' not in changed_options
@@ -478,6 +468,9 @@ class TestQtArgs:
     ])
     def test_qt_args(self, config_stub, args, expected, parser):
         """Test commandline with no Qt arguments given."""
+        # Avoid scrollbar overlay argument
+        config_stub.val.scrolling.bar = 'never'
+
         parsed = parser.parse_args(args)
         assert configinit.qt_args(parsed) == expected
 
@@ -494,7 +487,10 @@ class TestQtArgs:
     def test_with_settings(self, config_stub, parser):
         parsed = parser.parse_args(['--qt-flag', 'foo'])
         config_stub.val.qt.args = ['bar']
-        assert configinit.qt_args(parsed) == [sys.argv[0], '--foo', '--bar']
+        args = configinit.qt_args(parsed)
+        assert args[0] == sys.argv[0]
+        for arg in ['--foo', '--bar']:
+            assert arg in args
 
     @pytest.mark.parametrize('backend, expected', [
         (usertypes.Backend.QtWebEngine, True),
@@ -541,23 +537,33 @@ class TestQtArgs:
             assert '--disable-in-process-stack-traces' in args
             assert '--enable-in-process-stack-traces' not in args
 
-    @pytest.mark.parametrize('flags, expected', [
-        ([], []),
-        (['--debug-flag', 'chromium'], ['--enable-logging', '--v=1']),
+    @pytest.mark.parametrize('flags, added', [
+        ([], False),
+        (['--debug-flag', 'chromium'], True),
     ])
-    def test_chromium_debug(self, monkeypatch, parser, flags, expected):
+    def test_chromium_debug(self, monkeypatch, parser, flags, added):
         monkeypatch.setattr(configinit.objects, 'backend',
                             usertypes.Backend.QtWebEngine)
         parsed = parser.parse_args(flags)
-        assert configinit.qt_args(parsed) == [sys.argv[0]] + expected
+        args = configinit.qt_args(parsed)
 
-    def test_disable_gpu(self, config_stub, monkeypatch, parser):
+        for arg in ['--enable-logging', '--v=1']:
+            assert (arg in args) == added
+
+    @pytest.mark.parametrize('config, added', [
+        ('none', False),
+        ('qt-quick', False),
+        ('software-opengl', False),
+        ('chromium', True),
+    ])
+    def test_disable_gpu(self, config, added,
+                         config_stub, monkeypatch, parser):
         monkeypatch.setattr(configinit.objects, 'backend',
                             usertypes.Backend.QtWebEngine)
-        config_stub.val.qt.force_software_rendering = 'chromium'
+        config_stub.val.qt.force_software_rendering = config
         parsed = parser.parse_args([])
-        expected = [sys.argv[0], '--disable-gpu']
-        assert configinit.qt_args(parsed) == expected
+        args = configinit.qt_args(parsed)
+        assert ('--disable-gpu' in args) == added
 
     @utils.qt510
     @pytest.mark.parametrize('new_version, autoplay, added', [
@@ -705,6 +711,35 @@ class TestQtArgs:
 
         assert ('--force-dark-mode' in args) == added
 
+    @pytest.mark.parametrize('bar, new_qt, is_mac, added', [
+        # Overlay bar enabled
+        ('overlay', True, False, True),
+        # No overlay on mac
+        ('overlay', True, True, False),
+        ('overlay', False, True, False),
+        # No overlay on old Qt
+        ('overlay', False, False, False),
+        # Overlay disabled
+        ('when-searching', True, False, False),
+        ('always', True, False, False),
+        ('never', True, False, False),
+    ])
+    def test_overlay_scrollbar(self, config_stub, monkeypatch, parser,
+                               bar, new_qt, is_mac, added):
+        monkeypatch.setattr(configinit.objects, 'backend',
+                            usertypes.Backend.QtWebEngine)
+        monkeypatch.setattr(configinit.qtutils, 'version_check',
+                            lambda version, exact=False, compiled=True:
+                            new_qt)
+        monkeypatch.setattr(configinit.utils, 'is_mac', is_mac)
+
+        config_stub.val.scrolling.bar = bar
+
+        parsed = parser.parse_args([])
+        args = configinit.qt_args(parsed)
+
+        assert ('--enable-features=OverlayScrollbar' in args) == added
+
     @utils.qt514
     def test_blink_settings(self, config_stub, monkeypatch, parser):
         monkeypatch.setattr(configinit.objects, 'backend',
